@@ -161,7 +161,10 @@ def getInstalledVideo(prefix="/"):
 
 def getDistfilesVideo(prefix="/"):
     """Get video drivers from distfiles"""
-    distFiles = path.join(prefix, "usr/portage/distfiles")
+    if os.path.isdir('/var/db/repos/gentoo'):
+        distFiles = path.join(prefix, "var/calculate/distfiles")
+    else:
+        distFiles = path.join(prefix, "usr/portage/distfiles")
     driver_map = {'ati': 'fglrx',
                   'amd': 'fglrx',
                   'radeon': 'fglrx',
